OS := $(shell uname)

# Pick a compiler suite
COMPILER = GNU
#COMPILER = INTEL


# Pick compilation flags for debugging/production
#DEBUG := true
DEBUG := false


# Boost libraries
BOOSTROOT := /sw/opt/boost-1_55
#BOOSTROOT := /usr/lib
BOOSTINC  := $(BOOSTROOT)/include 


# FFT libraries
FFT := fftw3
ifeq ($(OS), Darwin) 
   FFTLIBDIR := -L/sw/lib 
endif
FFTLIB = $(FFTLIBDIR) -l$(FFT)


## Blas/Lapack  library configuration

# MKL available
#HAVE_MKL = true
HAVE_MKL = false

#set MKL library paths
MKL        := /opt/intel/composerxe/mkl
MKLPATH    := $(MKL)/lib/intel64
MKLINCLUDE := $(MKL)/include

# If MKL then grab the link line for your architecture from
# https://software.intel.com/en-us/articles/intel-mkl-link-line-advisor
MKL_LD = -I$(MKLINCLUDE) -I$(MKLINCLUDE)/intel64/lp64 \
	-L$(MKLPATH) $(MKLPATH)/libmkl_blas95_lp64.a \
	$(MKLPATH)/libmkl_lapack95_lp64.a \
	-Wl,--start-group $(MKLPATH)/libmkl_intel_lp64.a \
	$(MKLPATH)/libmkl_core.a $(MKLPATH)/libmkl_sequential.a \
	-Wl,--end-group -lpthread -lm -ldl


# If the MKL isn't available then try for atlas
HAVE_ATLAS = true
#HAVE_ATLAS = false

#ATLASPATH := /usr/local/atlas/lib/
ATLASPATH := /usr/lib/atlas-base/
#ATLASPATH := /sw/lib/

# Otherwise we'll use the standard system libraries 

## End of user-defined variables 


LIBS = -L$(BOOSTROOT)/lib -lboost_program_options
LIBS += $(FFTLIB)

ifeq ($(HAVE_MKL),true) 
   LIBS += $(MKL_LD)
else ifeq ($(HAVE_ATLAS),true)
#   LIBS += -L$(ATLASPATH) -llapack -lptf77blas -lcblas -latlas -lpthread
   LIBS += -L$(ATLASPATH) -llapack -lf77blas -lcblas -latlas -lpthread
else
#   LIBS += -L/usr/lib/atlas-base/ -llapack -lptf77blas -latlas 
   LIBS += -L/usr/lib/atlas-base/ -llapack -lf77blas -latlas 
endif



#Compiler-specfic options
ifeq ($(COMPILER),GNU)

   FC := gfortran
   CC := g++
   LD := $(CC)
   MODULE_FLAG := -J 


   ## Compiling/Optimizations
   ifeq ($(DEBUG),true)

      FFLAGS := -O2 -g -pg -ggdb -fcheck=all -fopenmp
      CFLAGS := -O2 -g -pg -ggdb -Wall -W -std=c++0x
      LDFLAGS := -O2 -g -pg -ggdb -Wall -W

   else

      FFLAGS := -O3 -mtune=native -fopenmp 
      CFLAGS := -O3 -mtune=native -std=c++0x
      LDFLAGS := $(CFLAGS)

   endif

   ## Extra compile-time warnings
   FFLAGS += -Wall -W -Wsurprising -Wuninitialized -Wconversion -fimplicit-none 

   # Extra libraries needed by the compiler
   ifeq ($(OS), Darwin) 
      LIBS += -L/sw/lib/gcc4.8/lib/ -lgomp 
   endif

   LIBS += -lgfortran

else

   # Ifort compilation
   FC := ifort
   CC := icpc
   LD := $(FC)
   MODULE_FLAG := -module


   ifeq ($(DEBUG),true)
      # Debug
      FFLAGS  := -g -pg -check all -warn all -debug -fopenmp
      CFLAGS  := -g -pg -ggdb -Wall -debug -std=c++11 
      LDFLAGS := -g -pg -check all -warn all -debug -fopenmp
   else
      # Performance
      FFLAGS := -fast -fopenmp
      CFLAGS := $(FFLAGS) -std=c++11
      LDFLAGS := $(FFLAGS) -ipo-jobs2
   endif

   LIBS += -lstdc++ -lgfortran

endif





